from __future__ import absolute_import
input_name = '../examples/linear_elasticity/linear_elastic_probes.py'
output_name = 'test_linear_elastic_probes.vtk'

from tests_basic import TestInput
class Test(TestInput):
    pass
